// Regular expression to check if string is a valid UUID
// https://melvingeorge.me/blog/check-if-string-valid-uuid-regex-javascript
var uuidRegex = /^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$/;
var Stroganoff = /** @class */ (function () {
    function Stroganoff(_a) {
        var _b = _a.uuid, uuid = _b === void 0 ? false : _b, _c = _a.numbers, numbers = _c === void 0 ? 1 : _c, _d = _a.upper, upper = _d === void 0 ? 1 : _d, _e = _a.minLen, minLen = _e === void 0 ? 12 : _e, _f = _a.maxLen, maxLen = _f === void 0 ? 64 : _f, _g = _a.special, special = _g === void 0 ? 1 : _g, _h = _a.validMessage, validMessage = _h === void 0 ? 'Your password is stroganoff' : _h, _j = _a.invalidMessage, invalidMessage = _j === void 0 ? 'Beef stew' : _j, _k = _a.specific, specific = _k === void 0 ? true : _k;
        this.uuid = uuid;
        this.numbers = numbers;
        this.upper = upper;
        this.minLen = minLen;
        this.maxLen = maxLen;
        this.special = special;
        this.validMessage = validMessage;
        this.invalidMessage = invalidMessage;
        this.specific = specific;
        if (this.numbers <= 0) {
            throw new Error('A good password needs numbers. Set numbers to above above 0.');
        }
        if (this.upper <= 0) {
            throw new Error('A good password needs uppercase characters. Set upper to anything above 0.');
        }
        if (this.minLen <= 3) {
            throw new Error('A good password needs to be longer than 3 characters. Set minLen to anything above 3.');
        }
        if (this.minLen > this.maxLen) {
            throw new Error('Your minimum length can not be longer than your maximum length');
        }
        if (this.special <= 0) {
            throw new Error('A good password needs special characters. Set special to anything above 1.');
        }
        // Required uppercase count
        var reqUppers = Array(this.upper).fill('.*[A-Z]').join('');
        // Required numbers count
        var reqNumbers = Array(this.numbers).fill('.*[0-9]').join('');
        // Required special characters count
        var reqSpecial = Array(this.special).fill('.*[!@#$%()&*-^=+;<>?]').join('');
        var exp = "^(?=" + reqUppers + ")(?=" + reqSpecial + ")(?=" + reqNumbers + ").{" + minLen + "," + maxLen + "}$";
        this.expression = new RegExp(exp);
        this.upperExpression = new RegExp("^(?=" + reqUppers + ")");
        this.specialExpression = new RegExp("^(?=" + reqSpecial + ")");
        this.numberExpression = new RegExp("^(?=" + reqNumbers + ")");
    }
    Stroganoff.prototype.validateUUID = function (str) {
        // Do some tests before the regex so not just anything gets passed into regex
        if (str.length !== 36 || str.split('-').length !== 5) {
            return false;
        }
        // Final test with regex
        return uuidRegex.test(str);
    };
    Stroganoff.prototype.validate = function (input) {
        if (this.uuid && this.validateUUID(input.toLocaleLowerCase())) {
            return {
                valid: true,
                message: this.validMessage,
                specific: {
                    uuid: true,
                },
            };
        }
        var isValid = this.expression.test(input);
        // Password is valid & return specifics
        if (isValid && this.specific) {
            return {
                valid: true,
                message: this.validMessage,
                specific: {
                    numbers: true,
                    upper: true,
                    special: true,
                    minLen: true,
                    maxLen: true,
                },
            };
        }
        // Password is valid but don't return any specifics
        if (isValid) {
            return {
                valid: true,
                message: this.validMessage,
            };
        }
        // Password is
        if (!this.specific)
            return { valid: false, message: this.invalidMessage };
        return {
            valid: false,
            message: this.invalidMessage,
            specific: {
                numbers: this.numberExpression.test(input),
                upper: this.upperExpression.test(input),
                special: this.specialExpression.test(input),
                minLen: input.length > this.minLen,
                maxLen: input.length < this.maxLen,
            },
        };
    };
    return Stroganoff;
}());

export default Stroganoff;
//# sourceMappingURL=stroganoff.es5.js.map
